Officially supported platforms
==============================

Orange Pi based
---------------
* Armbian Bionic mainline kernel 4.14.y (Ubuntu-based)

Raspberry Pi based
------------------
* Raspbian Stretch Lite November 2018 (Debian-based)

PC based
--------
* Ubuntu Server 16.04 LTS (Xenial)
* Ubuntu Server 18.04 LTS (Bionic)
* Docker (guest: Alpine 3.8.1)
